==> e107-0.7.20.tbz: www/e107/e107_plugins/forum/newforumposts_menu_config.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system
|
|     (C)Steve Dunstan 2001-2002
|     http://e107.org
|     jalist@e107.org
|
|     Released under the terms and conditions of the
|     GNU General Public License (http://gnu.org).
|
|     $Source: /cvs_backup/e107_0.7/e107_plugins/forum/newforumposts_menu_config.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
$eplug_admin = TRUE;
require_once("../../class2.php");
if (!getperms("1")) {
	header("location:".e_BASE."index.php");
	 exit();
}
require_once(e_ADMIN."auth.php");
	
include_lan(e_PLUGIN."forum/languages/".e_LANGUAGE."/lan_newforumposts_menu.php");
	
if (isset($_POST['update_menu'])) {
	while (list($key, $value) = each($_POST)) {
		if ($value != NFP_9) {
			$menu_pref[$key] = $value;
		}
	}
	if (!$_POST['newforumposts_title']) {
		$menu_pref['newforumposts_title'] = 0;
	}
	$tmp = addslashes(serialize($menu_pref));
	$sql->db_Update("core", "e107_value='$tmp' WHERE e107_name='menu_pref' ");
	$ns->tablerender("", "<div style=\"text-align:center\"><b>".NFP_3."</b></div>");
}

$menu_pref['newforumposts_maxage'] = varset($menu_pref['newforumposts_maxage'],0);

$text = "<div style='text-align:center'>
	<form method=\"post\" action=\"".e_SELF."?".e_QUERY."\" name=\"menu_conf_form\">
	<table style='width:85%' class=\"fborder\">
	<colgroup>
	  <col style='width:40%;' />
	  <col style='width:60%;' />
	</colgroup>
	<tr>
	<td class='forumheader3'>".NFP_4.": </td>
	<td class='forumheader3'>
	<input class=\"tbox\" type=\"text\" name=\"newforumposts_caption\" size=\"20\" value=\"".$menu_pref['newforumposts_caption']."\" maxlength=\"100\" />
	</td>
	</tr>
	 
	<tr>
	<td class='forumheader3'>".NFP_5.":
	</td>
	<td class='forumheader3'>
	<input class=\"tbox\" type=\"text\" name=\"newforumposts_display\" size=\"20\" value=\"".$menu_pref['newforumposts_display']."\" maxlength=\"2\" />
	</td>
	</tr>
	 
	<tr>
	<td class='forumheader3'>".NFP_12.":
	</td>
	<td class='forumheader3'>
	<input class=\"tbox\" type=\"text\" name='newforumposts_maxage' size='20' value='".$menu_pref['newforumposts_maxage']."' maxlength='3' /><br />
	<span class='smalltext'><em>".NFP_13."</em></span>
	</td>
	</tr>
	 
	<tr>
	<td class='forumheader3'>".NFP_6.": </td>
	<td class='forumheader3'>
	<input class=\"tbox\" type=\"text\" name=\"newforumposts_characters\" size=\"20\" value=\"".$menu_pref['newforumposts_characters']."\" maxlength=\"4\" />
	</td>
	</tr>
	 
	<tr>
	<td class='forumheader3'>".NFP_7.":
	</td>
	<td class='forumheader3'>
	<input class=\"tbox\" type=\"text\" name=\"newforumposts_postfix\" size=\"30\" value=\"".$menu_pref['newforumposts_postfix']."\" maxlength=\"200\" />
	</td>
	</tr>
	 
	<tr>
	<td class='forumheader3'>".NFP_8.":</td>
	<td class='forumheader3'>
	<input type=\"checkbox\" name=\"newforumposts_title\" value=\"1\" ";
if ($menu_pref['newforumposts_title']) {
	$text .= " checked ";
}
$text .= "
	</td>
	</tr>
	 
	<tr style=\"vertical-align:top\">
	<td colspan=\"2\"  style=\"text-align:center\" class='forumheader'>
	<input class=\"button\" type=\"submit\" name=\"update_menu\" value=\"".NFP_9."\" />
	</td>
	</tr>
	</table>
	</form>
	</div>";
$ns->tablerender(NFP_10, $text);
require_once(e_ADMIN."footer.php");
?>

==> e107-1.0.3.tbz: www/e107/e107_plugins/forum/newforumposts_menu_config.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system
|
|     Copyright (C) 2001-2002 Steve Dunstan (jalist@e107.org)
|     Copyright (C) 2008-2010 e107 Inc (e107.org)
|
|
|     Released under the terms and conditions of the
|     GNU General Public License (http://gnu.org).
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_plugins/forum/newforumposts_menu_config.php $
|     $Revision: 11678 $
|     $Id: newforumposts_menu_config.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/
$eplug_admin = TRUE;
require_once("../../class2.php");
if (!getperms("1")) {
	header("location:".e_BASE."index.php");
	 exit();
}
require_once(e_ADMIN."auth.php");
	
include_lan(e_PLUGIN."forum/languages/".e_LANGUAGE."/lan_newforumposts_menu.php");
	
if (isset($_POST['update_menu'])) {
	while (list($key, $value) = each($_POST)) {
		if ($value != NFP_9) {
			$menu_pref[$key] = $value;
		}
	}
	if (!$_POST['newforumposts_title']) {
		$menu_pref['newforumposts_title'] = 0;
	}
	$tmp = addslashes(serialize($menu_pref));
	$sql->db_Update("core", "e107_value='$tmp' WHERE e107_name='menu_pref' ");
	$ns->tablerender("", "<div style=\"text-align:center\"><b>".NFP_3."</b></div>");
}

$menu_pref['newforumposts_maxage'] = varset($menu_pref['newforumposts_maxage'],0);

$text = "<div style='text-align:center'>
	<form method=\"post\" action=\"".e_SELF."?".e_QUERY."\" name=\"menu_conf_form\">
	<table style='width:85%' class=\"fborder\">
	<colgroup>
	  <col style='width:40%;' />
	  <col style='width:60%;' />
	</colgroup>
	<tr>
	<td class='forumheader3'>".NFP_4.": </td>
	<td class='forumheader3'>
	<input class=\"tbox\" type=\"text\" name=\"newforumposts_caption\" size=\"20\" value=\"".$menu_pref['newforumposts_caption']."\" maxlength=\"100\" />
	</td>
	</tr>
	 
	<tr>
	<td class='forumheader3'>".NFP_5.":
	</td>
	<td class='forumheader3'>
	<input class=\"tbox\" type=\"text\" name=\"newforumposts_display\" size=\"20\" value=\"".$menu_pref['newforumposts_display']."\" maxlength=\"2\" />
	</td>
	</tr>
	 
	<tr>
	<td class='forumheader3'>".NFP_12.":
	</td>
	<td class='forumheader3'>
	<input class=\"tbox\" type=\"text\" name='newforumposts_maxage' size='20' value='".$menu_pref['newforumposts_maxage']."' maxlength='3' /><br />
	<span class='smalltext'><em>".NFP_13."</em></span>
	</td>
	</tr>
	 
	<tr>
	<td class='forumheader3'>".NFP_6.": </td>
	<td class='forumheader3'>
	<input class=\"tbox\" type=\"text\" name=\"newforumposts_characters\" size=\"20\" value=\"".$menu_pref['newforumposts_characters']."\" maxlength=\"4\" />
	</td>
	</tr>
	 
	<tr>
	<td class='forumheader3'>".NFP_7.":
	</td>
	<td class='forumheader3'>
	<input class=\"tbox\" type=\"text\" name=\"newforumposts_postfix\" size=\"30\" value=\"".$menu_pref['newforumposts_postfix']."\" maxlength=\"200\" />
	</td>
	</tr>
	 
	<tr>
	<td class='forumheader3'>".NFP_8.":</td>
	<td class='forumheader3'>
	<input type=\"checkbox\" name=\"newforumposts_title\" value=\"1\" ";
if ($menu_pref['newforumposts_title']) {
	$text .= " checked ";
}
$text .= "
	</td>
	</tr>
	 
	<tr style=\"vertical-align:top\">
	<td colspan=\"2\"  style=\"text-align:center\" class='forumheader'>
	<input class=\"button\" type=\"submit\" name=\"update_menu\" value=\"".NFP_9."\" />
	</td>
	</tr>
	</table>
	</form>
	</div>";
$ns->tablerender(NFP_10, $text);
require_once(e_ADMIN."footer.php");
?>
